@@ -1,3 +1,15 @@
+--  Licensed under the Apache License, Version 2.0 (the "License");
+--  you may not use this file except in compliance with the License.
+--  You may obtain a copy of the License at
+--
+--      http://www.apache.org/licenses/LICENSE-2.0
+--
+--  Unless required by applicable law or agreed to in writing, software
+--  distributed under the License is distributed on an "AS IS" BASIS,
+--  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+--  See the License for the specific language governing permissions and
+--  limitations under the License.
+--
 CREATE OR REPLACE FUNCTION __temp_minimum_cluster_compat_level()
   RETURNS TABLE(cluster_name VARCHAR(40), cluster_compat_version VARCHAR(40)) AS
 $PROCEDURE$
@@ -42,6 +54,6 @@ Copy (
     __temp_minimum_cluster_compat_level()
   ORDER BY
     cluster_name
-) To STDOUT With CSV DELIMITER E'\|' HEADER;
+) TO STDOUT WITH CSV DELIMITER E'\|' HEADER;
 
 DROP FUNCTION __temp_minimum_cluster_compat_level();
